@@ -1,6 +1,15 @@
-## ---- include = FALSE---------------------------------------------------------
+## ----include = FALSE----------------------------------------------------------
 knitr::opts_chunk$set(collapse=TRUE, comment = "#>")
 
+## ----setup2, echo=TRUE, eval=FALSE--------------------------------------------
+# if(!requireNamespace("wrMisc", quietly=TRUE)) install.packages("wrMisc")   # required underneath
+# install.packages("wrGraph")
+
+## ----setup3, echo=TRUE, eval=FALSE--------------------------------------------
+# if(!requireNamespace("ggplot2", quietly=TRUE)) install.packages("ggplot2")   # also required
+# if(!requireNamespace("FactoMineR", quietly=TRUE)) install.packages("FactoMineR")
+# if(!requireNamespace("factoextra", quietly=TRUE)) install.packages("factoextra")
+
 ## ----setup, echo=FALSE, messages=FALSE, warnings=FALSE------------------------
 suppressPackageStartupMessages({
     library(wrMisc)
@@ -9,16 +18,9 @@ suppressPackageStartupMessages({
     library(factoextra)
 })
 
-## ----setup2, echo=TRUE, eval=FALSE--------------------------------------------
-#  install.packages("wrGraph")
-
-## ----setup3, echo=TRUE, eval=FALSE--------------------------------------------
-#  if(!requireNamespace("FactoMineR", quietly=TRUE)) install.packages("FactoMineR")
-#  if(!requireNamespace("factoextra", quietly=TRUE)) install.packages("factoextra")
-
 ## ----vignBrowse, echo=TRUE, eval=FALSE----------------------------------------
-#  # access vignette :
-#  browseVignettes("wrGraph")    #  ... and the select the html output
+# # access vignette :
+# browseVignettes("wrGraph")    #  ... and the select the html output
 
 ## ----setup4, echo=TRUE--------------------------------------------------------
 library("wrMisc")
@@ -27,7 +29,7 @@ library("wrGraph")
 packageVersion("wrGraph")
 
 ## ----partitionPlot1, out.width="110%", out.heigth="110%", echo=TRUE-----------
-## as the last column of the iris-data is not numeric we choose -1
+## as the last column of the Iris-data is not numeric we choose -1
 (part <- partitionPlot(ncol(iris)-1))
 layout(part)
 for(i in colnames(iris)[-5]) hist(iris[,i], main=i)
@@ -58,27 +60,31 @@ for(i in 1:4) histW(iris[,i], isLog=FALSE, tit=colnames(iris)[i])
 
 ## ----Hist5, out.width="110%", out.heigth="150%", echo=TRUE--------------------
 layout(1)
-plot(iris[,1:2], col=rgb(0.4,0.4,0.4,0.3), pch=16, main="Iris data")
+plot(iris[,1:2], col=rgb(0.4,0.4,0.4,0.3), pch=16, main="Iris Data")
 legendHist(iris[,1], loc="br", legTit=colnames(iris)[1], cex=0.5)
 legendHist(iris[,2], loc="tl", legTit=colnames(iris)[2], cex=0.5)
 
-## ----vioplot1, echo=TRUE------------------------------------------------------
-vioplotW(iris[,-5], tit="Iris-data")
+## ----vioplot1, fig.height=6, fig.width=8, echo=TRUE---------------------------
+vioplotW(iris[,-5], tit="Iris-Data Violin Plot")
 
-## ----vioplot2, echo=TRUE------------------------------------------------------
-## less sloothing
-vioplotW(iris[,-5], tit="Iris-data", hh=0.15)
+## ----vioplot2, fig.height=6, fig.width=8, echo=TRUE---------------------------
+## less smoothing
+vioplotW(iris[,-5], tit="Iris-Data Violin Plot ('nervous')", hh=0.15)
+
+## ----vioplot3, fig.height=6, fig.width=6, echo=TRUE---------------------------
+## less smoothing
+vioplotW(iris[,-5], tit="Paired Iris-Data Violin Plot ", halfViolin="pairwise")
 
 ## ----cumFrqPlot1, echo=TRUE---------------------------------------------------
 cumFrqPlot(iris[,1:4])
 
 ## ----imageW, echo=TRUE--------------------------------------------------------
 par(mar=c(4, 5.5, 4, 1))  
-imageW(as.matrix(iris[1:40,1:4]), transp=FALSE, tit="Iris-data (head)")
+imageW(as.matrix(iris[1:40,1:4]), transp=FALSE, tit="Iris-Data (head)")
 
 ## ----imageW2, fig.height=2.5, fig.width=9, fig.align="center", echo=TRUE------
 imageW(as.matrix(iris[1:20,1:4]), latticeVersion=TRUE, transp=FALSE, col=c("blue","red"), 
-  rotXlab=45, yLab="Observation no", tit="Iris-data (head)")
+  rotXlab=45, yLab="Observation no", tit="Iris-Data (head)")
 
 ## ----imageW3, fig.height=6, fig.width=5, echo=TRUE----------------------------
 ma1 <- matrix(-7:16,nc=4,dimnames=list(letters[1:6],LETTERS[1:4]))
@@ -98,9 +104,9 @@ irisC <- sapply(thr,function(x) colSums(iris[,1:4] < x))
 irisC <- cbind(thr,t(irisC))
 
   head(irisC)
-staggerdCountsPlot(irisC[,], countsCol=colnames(iris)[1:4], tit="Iris-data")
-staggerdCountsPlot(irisC[,], varCountNa="Sepal", tit="Iris-data")
-staggerdCountsPlot(irisC[,], varCountNa="Sepal", tit="Iris-data (log-scale)", logScale=TRUE)
+staggerdCountsPlot(irisC[,], countsCol=colnames(iris)[1:4], tit="Iris-Data")
+staggerdCountsPlot(irisC[,], varCountNa="Sepal", tit="Iris-Data")
+staggerdCountsPlot(irisC[,], varCountNa="Sepal", tit="Iris-Data (log-scale)", logScale=TRUE)
 
 ## ----plotBy2Groups1, echo=TRUE------------------------------------------------
 dat <- iris[which(iris$Species %in% c("setosa","versicolor")),]
@@ -108,42 +114,49 @@ plotBy2Groups(dat$Sepal.Length, gl(2,50,labels=c("setosa","versicolor")),
   gl(20,5), yLab="Sepal.Length")
 
 ## ----plotLinReg1, echo=TRUE---------------------------------------------------
-plotLinReg(iris$Sepal.Length, iris$Petal.Width, tit="Iris-data")
+plotLinReg(iris$Sepal.Length, iris$Petal.Width, tit="Iris-Data")
 
 ## ----PCA1, fig.height=7, fig.width=7, echo=TRUE-------------------------------
 ## the basic way
 iris.prc <- prcomp(iris[,1:4], scale.=TRUE)
 biplot(iris.prc)              # traditional plot
 
-## ----PCA3, echo=TRUE----------------------------------------------------------
+## ----PCA3a, echo=TRUE---------------------------------------------------------
 ## via FactoMineR
 chPa <- c(requireNamespace("FactoMineR", quietly=TRUE), requireNamespace("dplyr", quietly=TRUE), 
-  requireNamespace("factoextra", quietly=TRUE))
+  requireNamespace("factoextra", quietly=TRUE), requireNamespace("ggpubr", quietly=TRUE) )
+
+## ----PCA3b, echo=TRUE---------------------------------------------------------
 if(all(chPa)) {
   library(FactoMineR); library(dplyr); library(factoextra)
   iris.Fac <- PCA(iris[,1:4],scale.unit=TRUE, graph=FALSE)
-  fviz_pca_ind(iris.Fac, geom.ind="point", col.ind=iris$Species, palette=c(2,4,3), 
-    addEllipses=TRUE, legend.title="Groups" )
-} else message("You need to install packages 'dplyr', 'FactoMineR' and 'factoextra' for this figure")  
+  iris.Fac2 <- try(fviz_pca_ind(iris.Fac, geom.ind="point", col.ind=iris$Species, palette=c(2,4,3), 
+    addEllipses=TRUE, legend.title="Groups"))
+  if(inherits(iris.Fac2, "try-error")) message("Problem running factoextra ..") else {
+    iris.Fac2 <- try(plot(iris.Fac2))  
+    if(inherits(iris.Fac2, "try-error")) message("A problem occured when trying to print from factoextra !!") }    
+} else message("You need to install packages 'dplyr', 'FactoMineR' and 'factoextra' for this figure ! ",
+  "Check the messages of library() if there are other packages that may be missing (and need to get installed first)")  
 
 
 ## ----PCA4, echo=TRUE----------------------------------------------------------
 ## via wrGraph, similar to FactoMineR but with bagplots
 plotPCAw(t(as.matrix(iris[,-5])), gl(3,50,labels=c("setosa","versicolor","virginica")),
-  tit="Iris data", rowTyName="types of leaves", suplFig=FALSE, cexTxt=1.3, rotatePC=2)
+  tit="Iris Data", rowTyName="types of leaves", suplFig=FALSE, cexTxt=1.3, rotatePC=2)
 
 ## ----PCA5, fig.height=12, fig.width=9, fig.align="center", echo=TRUE----------
 ## including 3rd component and Screeplot
 plotPCAw(t(as.matrix(iris[,-5])), gl(3,50,labels=c("setosa","versicolor","virginica")),
-  tit="Iris data", rowTyName="types of leaves", cexTxt=2)
+  tit="Iris Data PCA", rowTyName="types of leaves", cexTxt=2)
 
 
-## ----PCA6, fig.height=12, fig.width=9, fig.align="center", echo=TRUE----------
+## ----PCA6, fig.height=7.5, fig.width=9, fig.align="center", echo=TRUE---------
 ## creat copy of data and add rownames
 irisD <- as.matrix(iris[,-5])
 rownames(irisD) <- paste(iris$Species, rep(1:50,3), sep="_")
-plotPCAw(t(irisD), gl(3,50,labels=c("setosa","versicolor","virginica")), tit="Iris data", 
-  rowTyName="types of leaves", suplFig=FALSE, cexTxt=1.3, rotatePC=2, pointLabelPar=list(textCex=0.45))
+## plot
+plotPCAw(t(irisD), gl(3,50,labels=c("setosa","versicolor","virginica")), tit="Iris Data PCA", 
+  rowTyName="types of leaves", suplFig=FALSE, cexTxt=1.6, rotatePC=2, pointLabelPar=list(textCex=0.48))
 
 ## ----MA0, fig.height=6, fig.width=8, fig.align="center", echo=TRUE------------
 ## toy data
@@ -179,7 +192,9 @@ gr3 <- gl(3,3,labels=c("C","A","B"))
 tRes2 <- moderTest2grp(mat[,1:6], gl(2,3))
 
 VolcanoPlotW(tRes2)
-VolcanoPlotW(tRes2, FCth=1.3, FdrThrs=0.2, namesNBest="pass")
+
+# now with thresholds, labels and arrow for expected ratio
+VolcanoPlotW(tRes2, FCth=1.3, FdrThrs=0.2, namesNBest="pass", expFCarrow=c(0.75,2))
 
 ## ----Volc2,  fig.height=6, fig.width=9.5, fig.align="center", echo=TRUE-------
 ## assume 3 groups with 3 samples each
